summaryrefslogtreecommitdiffstats
path: root/lib/private
diff options
context:
space:
mode:
Diffstat (limited to 'lib/private')
-rw-r--r--lib/private/Security/Normalizer/IpAddress.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/Security/Normalizer/IpAddress.php b/lib/private/Security/Normalizer/IpAddress.php
index b471c499440..9e7d84e7e3f 100644
--- a/lib/private/Security/Normalizer/IpAddress.php
+++ b/lib/private/Security/Normalizer/IpAddress.php
@@ -92,7 +92,7 @@ class IpAddress {
}
/**
* Gets either the /32 (IPv4) or the /128 (IPv6) subnet of an IP address
*
* @return string
*/
@@ -105,7 +105,7 @@ class IpAddress {
}
return $this->getIPv6Subnet(
$this->ip,
- 128
+ 64
);
}
@@ -92,7 +92,7 @@ class IpAddress {
}
/**
- * Gets either the /32 (IPv4) or the /128 (IPv6) subnet of an IP address
+ * Gets either the /32 (IPv4) or the /64 (IPv6) subnet of an IP address
*
* @return string